@@ -141,6 +141,7 @@
 #'   - `exact`: Logical flag indicating whether calculations are exact or not.
 #'   - `txt`: Summary text.
 #'   - `predictions`: \eqn{(n \times K)} matrix with predictions of `X`.
+#'   - `algorithm`: "kernelshap".
 #' @references
 #'   1. Scott M. Lundberg and Su-In Lee. A unified approach to interpreting model 
 #'     predictions. Proceedings of the 31st International Conference on Neural 
@@ -318,7 +319,8 @@ kernelshap.default <- function(object, X, bg_X, pred_fun = stats::predict,
     prop_exact = prop_exact,
     exact = exact || trunc(p / 2) == hybrid_degree,
     txt = txt,
-    predictions = v1
+    predictions = v1,
+    algorithm = "kernelshap"
   )
   class(out) <- "kernelshap"
   out
@@ -355,36 +357,3 @@ kernelshap.ranger <- function(object, X, bg_X,
   )
 }
 
-#' @describeIn kernelshap Kernel SHAP method for "mlr3" models, see Readme for an example.
-#' @export
-kernelshap.Learner <- function(object, X, bg_X,
-                               pred_fun = NULL,
-                               feature_names = colnames(X),
-                               bg_w = NULL, exact = length(feature_names) <= 8L,
-                               hybrid_degree = 1L + length(feature_names) %in% 4:16,
-                               paired_sampling = TRUE,
-                               m = 2L * length(feature_names) * (1L + 3L * (hybrid_degree == 0L)),
-                               tol = 0.005, max_iter = 100L, parallel = FALSE,
-                               parallel_args = NULL, verbose = TRUE, ...) {
-  if (is.null(pred_fun)) {
-    pred_fun <- mlr3_pred_fun(object, X = X)
-  }
-  kernelshap.default(
-    object = object,
-    X = X,
-    bg_X = bg_X,
-    pred_fun = pred_fun,
-    feature_names = feature_names,
-    bg_w = bg_w,
-    exact = exact,
-    hybrid_degree = hybrid_degree,
-    paired_sampling = paired_sampling,
-    m = m,
-    tol = tol,
-    max_iter = max_iter,
-    parallel = parallel,
-    parallel_args = parallel_args,
-    verbose = verbose,
-    ...
-  )
-}
