@@ -226,7 +226,8 @@ case_p1 <- function(n, feature_names, v0, v1, X, verbose) {
     prop_exact = 1,
     exact = TRUE,
     txt = txt,
-    predictions = v1
+    predictions = v1,
+    algorithm = "kernelshap"
   )
   class(out) <- "kernelshap"
   out
@@ -380,26 +381,3 @@ prep_w <- function(w, bg_n) {
   if (!is.double(w)) as.double(w) else w
 }
 
-#' mlr3 Helper
-#' 
-#' Returns the prediction function of a mlr3 Learner.
-#' 
-#' @noRd
-#' @keywords internal
-#' 
-#' @param object Learner object.
-#' @param X Dataframe like object.
-#' 
-#' @returns A function.
-mlr3_pred_fun <- function(object, X) {
-  if ("classif" %in% object$task_type) {
-    # Check if probabilities are available
-    test_pred <- object$predict_newdata(utils::head(X))
-    if ("prob" %in% test_pred$predict_types) {
-      return(function(m, X) m$predict_newdata(X)$prob)
-    } else {
-      stop("Set lrn(..., predict_type = 'prob') to allow for probabilistic classification.")
-    }
-  }
-  function(m, X) m$predict_newdata(X)$response
-}
